@@ -90,16 +90,16 @@ class LengthNotifierPlugin(GajimPlugin):
             # Not restricted to any JIDs
             return True
 
-        current_jid = JID(jid)
+        current_jid = JID.from_string(jid)
         allowed_jids = self.config['JIDS'].split(',')
         for allowed_jid in allowed_jids:
             try:
-                address = JID(allowed_jid.strip())
+                address = JID.from_string(allowed_jid.strip())
             except Exception as error:
                 log.debug('Error parsing JID: %s (%s)' % (error, allowed_jid))
                 continue
-            if address.isDomain:
-                if current_jid.getDomain() == address:
+            if address.is_domain:
+                if current_jid.domain == address:
                     log.debug('Add counter for Domain %s' % address)
                     return True
             if current_jid == address:
@@ -110,7 +110,7 @@ class LengthNotifierPlugin(GajimPlugin):
         if not app.plugin_manager.get_active_plugin('length_notifier'):
             # Don’t update if the plugin is disabled
             return
-        for control in app.interface.msg_win_mgr.get_controls():
+        for control in app.window.get_controls():
             self._disconnect_chat_control(control)
             self._connect_chat_control(control)
 
